@@ -1,13 +1,8 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2012-2019 Rumma & Ko Ltd
+# Copyright 2012-2020 Rumma & Ko Ltd
 # License: BSD (see file COPYING for details)
 
 
-from __future__ import unicode_literals
-
-from builtins import str
-import six
-
 from html import escape
 from os import path
 from django.conf import settings
@@ -32,7 +27,7 @@ from lino.core.boundaction import BoundAction
 from lino.core.choicelists import ChoiceListMeta
 from lino.core.actors import Actor
 from lino.core.layouts import LayoutHandle
-from lino.core.elems import LayoutElement, ComboFieldElement, SimpleRemoteComboFieldElement
+from lino.core.elems import LayoutElement, ComboFieldElement, SimpleRemoteComboFieldElement, FieldElement
 from lino.core import kernel
 
 from etgen.html import E
@@ -84,9 +79,9 @@ class Renderer(JsRenderer, JsCacheRenderer):
         """
         self.serialise_js_code = True
         choicelists_data = {
-            ID: [{"value": py2js(c[0]).strip('"'), "text": py2js(c[1]).strip('"')} for c in cl.get_choices()] for
-            ID, cl in
-            kernel.CHOICELISTS.items()}
+            # ID: [{"value": py2js(c[0]).strip('"'), "text": py2js(c[1]).strip('"')} for c in cl.get_choices()] for
+            ID: [{"value": c[0].value, "text": str(c[1])} for c in cl.get_choices()]
+                for ID, cl in kernel.CHOICELISTS.items()}
 
         actions = set()
         for rpt in self.actors_list:
@@ -290,7 +285,7 @@ class Renderer(JsRenderer, JsCacheRenderer):
                           react_name=v.__class__.__name__)  # Used for choosing correct react component
             if hasattr(v, "elements"):  # dd
                 result['items'] = [e for e in v.elements if e.get_view_permission(get_user_profile())]
-            result.update(obj2dict(v, " fields_index fields_index_hidden editable vertical hpad is_fieldset name width preferred_width\
+            result.update(obj2dict(v, "fields_index fields_index_hidden editable vertical hpad is_fieldset name width preferred_width\
                                       hidden value hflex vflex"))
             # result["width"] = v.width or v.preferred_width
             # Slave tables
@@ -298,8 +293,10 @@ class Renderer(JsRenderer, JsCacheRenderer):
                 # reference to actor data for slave-grids
                 result.update(obj2dict(v.actor, "actor_id"))  # to get siteDate layout index
 
-            if hasattr(v, "get_field_options"):
+            # if hasattr(v, "get_field_options"):
+            if issubclass(v.__class__, FieldElement):
                 result.update(field_options=v.get_field_options())
+                result.update(help_text=v.field.help_text)
 
             return result
         if isinstance(v, LayoutHandle):
@@ -490,7 +487,7 @@ class Renderer(JsRenderer, JsCacheRenderer):
         if not js:
             return None
         # Convert to string as currently window actions are py2js => dict
-        if not isinstance(js, six.string_types):
+        if not isinstance(js, str):
             js = str(js)
         js = escape(js, quote=False)
         return 'javascript:' + js
