@@ -1,15 +1,18 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2009-2018 Rumma & Ko Ltd
+# Copyright 2009-2020 Rumma & Ko Ltd
 # License: BSD (see file COPYING for details)
 
 """Views for `lino_react.react`.
 """
 
-# from __future__ import division
-
 from os import environ
-
+import re
+import cgi
 import ast
+import json
+from jinja2.exceptions import TemplateNotFound
+from etgen.html import E, tostring
+from etgen import html as xghtml
 
 from django import http
 from django.db import models
@@ -25,34 +28,21 @@ from lino.core import auth
 from lino.utils import isiterable
 from lino.utils.jsgen import py2js
 from lino.core import fields
-
+from lino.core.elems import ComboFieldElement
+from lino.core.fields import choices_for_field
 from lino.core.gfks import ContentType
-
-# from lino.api import dd
 from lino.core import constants
-# from lino.core import auth
 from lino.core.requests import BaseRequest
 from lino.core.tablerequest import TableRequest
-import json
-
 from lino.core.views import requested_actor, action_request
 from lino.core.views import json_response, json_response_kw
-
-from lino.core.views import action_request
+from lino.core.views import choices_response
 from lino.core.utils import navinfo
-from etgen.html import E, tostring
-from etgen import html as xghtml
 from lino.core import kernel
 
 from lino.modlib.users.utils import get_user_profile, with_user_profile
-
 from lino.api import rt
-import re
-import cgi
-
-from lino.core.elems import ComboFieldElement
-
-from jinja2.exceptions import TemplateNotFound
+from lino.modlib.extjs.views import ApiElement, elem2rec_empty
 
 
 def find(itter, target, key=None):
@@ -71,106 +61,11 @@ def find(itter, target, key=None):
 # Taken from lino.modlib.extjs.views
 NOT_FOUND = "%s has no row with primary key %r"
 
-
-def elem2rec_empty(ar, ah, elem, **rec):
-    """
-    Returns a dict of this record, designed for usage by an EmptyTable.
-    """
-    # ~ rec.update(data=rh.store.row2dict(ar,elem))
-    rec.update(data=elem._data)
-    # ~ rec = elem2rec1(ar,ah,elem)
-    # ~ rec.update(title=_("Insert into %s...") % ar.get_title())
-    rec.update(title=ar.get_action_title())
-    rec.update(id=-99998)
-    # ~ rec.update(id=elem.pk) or -99999)
-    if ar.actor.parameters:
-        rec.update(
-            param_values=ar.actor.params_layout.params_store.pv2dict(
-                ar, ar.param_values))
-    return rec
-
-
 # class Callbacks(View):
 #     def get(self, request, thread_id, button_id):
 #         return settings.SITE.kernel.run_callback(request, thread_id, button_id)
 
-
-class ApiElement(View):
-    def get(self, request, app_label=None, actor=None, pk=None):
-        ui = settings.SITE.kernel
-        rpt = requested_actor(app_label, actor)
-
-        action_name = request.GET.get(constants.URL_PARAM_ACTION_NAME,
-                                      rpt.default_elem_action_name)
-        ba = rpt.get_url_action(action_name)
-        if ba is None:
-            raise http.Http404("%s has no action %r" % (rpt, action_name))
-
-        if pk and pk != '-99999' and pk != '-99998':
-            # ~ ar = ba.request(request=request,selected_pks=[pk])
-            # ~ print 20131004, ba.actor
-            # Use url selected rows as selected PKs if defined, otherwise use the PK defined in the url path
-            sr = request.GET.getlist(constants.URL_PARAM_SELECTED)
-            if not sr:
-                sr = [pk]
-            ar = ba.request(request=request, selected_pks=sr)
-            elem = ar.selected_rows[0]
-        else:
-            ar = ba.request(request=request)
-            elem = None
-
-        ar.renderer = ui.default_renderer
-        ah = ar.ah
-
-        fmt = request.GET.get(
-            constants.URL_PARAM_FORMAT, ba.action.default_format)
-
-        if not ar.get_permission():
-            msg = "No permission to run {}".format(ar)
-            # raise Exception(msg)
-            raise PermissionDenied(msg)
-
-        if ba.action.opens_a_window:
-            # print("15022019", action_name)
-            if fmt == constants.URL_FORMAT_JSON:
-                if pk == '-99999':
-                    elem = ar.create_instance()
-                    datarec = ar.elem2rec_insert(ah, elem)
-                elif pk == '-99998':
-                    elem = ar.create_instance()
-                    datarec = elem2rec_empty(ar, ah, elem)
-                elif elem is None:
-                    datarec = dict(
-                        success=False, message=NOT_FOUND % (rpt, pk))
-                else:
-                    datarec = ar.elem2rec_detailed(elem)
-                return json_response(datarec)
-
-            after_show = ar.get_status(record_id=pk)
-            tab = request.GET.get(constants.URL_PARAM_TAB, None)
-            if tab is not None:
-                tab = int(tab)
-                after_show.update(active_tab=tab)
-
-            return http.HttpResponse(
-                ui.default_renderer.html_page(
-                    request, ba.action.label,
-                    on_ready=ui.default_renderer.action_call(
-                        request, ba, after_show)))
-
-        # if isinstance(ba.action, actions.RedirectAction):
-        #     target = ba.action.get_target_url(elem)
-        #     if target is None:
-        #         raise http.Http404("%s failed for %r" % (ba, elem))
-        #     return http.HttpResponseRedirect(target)
-
-        if pk == '-99998':
-            assert elem is None
-            elem = ar.create_instance()
-            ar.selected_rows = [elem]
-        elif elem is None:
-            raise http.Http404(NOT_FOUND % (rpt, pk))
-        return settings.SITE.kernel.run_action(ar)
+class ApiElement(ApiElement):
 
     def post(self, request, app_label=None, actor=None, pk=None):
         data = http.QueryDict(request.body)
@@ -286,90 +181,6 @@ class ApiList(View):
         return settings.SITE.kernel.run_action(ar)
 
 
-# Should we Refactor into lino.modlib.extjs.choicees_views.py and import?
-# choices_for_field is copied line-for-line from
-# lino.modlib.extjs.views.choices_for_field
-
-# 20200425 I saw no difference in the two versions, and I added two lines to the
-# choices_for_field in extjs.  IMO we should import it here. And before moving extjs
-# out of Lino, move choices_for_field to another module, e.g. to lino.core.fields.
-
-from lino.modlib.extjs.views import choices_for_field
-
-
-# choices_response is copied line-for-line from lino.modlib.extjs.views.choices_response
-def choices_response(actor, request, qs, row2dict, emptyValue, field=None):
-    """
-    :param actor: requesting Actor
-    :param request: web request
-    :param qs: list of django model QS,
-    :param row2dict: function for converting data set into a dict for json
-    :param emptyValue: The Text value to represent None in the choice-list
-    :param is_blank_value: The Text value to represent filtering rows that are blank in PV the choice-list
-    :param is_not_blank_value: The Text value to represent filtering rows that are not blank in PV the choice-list
-
-    :return: json web responce
-
-    Filters data-set acording to quickseach
-    Counts total rows in the set,
-    Calculates offset and limit
-    Adds None value
-    returns
-    """
-    quick_search = request.GET.get(constants.URL_PARAM_FILTER, None)
-    offset = request.GET.get(constants.URL_PARAM_START, None)
-    limit = request.GET.get(constants.URL_PARAM_LIMIT, None)
-    wt = request.GET.get(constants.URL_PARAM_WINDOW_TYPE, None)
-
-    if isinstance(qs, models.QuerySet):
-        qs = qs.filter(qs.model.quick_search_filter(quick_search)) if quick_search else qs
-        count = qs.count()
-
-        if offset:
-            qs = qs[int(offset):]
-            # ~ kw.update(offset=int(offset))
-
-        if limit:
-            # ~ kw.update(limit=int(limit))
-            qs = qs[:int(limit)]
-
-        rows = [row2dict(row, {}) for row in qs]
-
-    else:
-        rows = [row2dict(row, {}) for row in qs]
-        if quick_search:
-            txt = quick_search.lower()
-
-            rows = [row for row in rows
-                    if txt in row[constants.CHOICES_TEXT_FIELD].lower()]
-        count = len(rows)
-        rows = rows[int(offset):] if offset else rows
-        rows = rows[:int(limit)] if limit else rows
-
-    if wt == constants.WINDOW_TYPE_PV and field and field.blank:
-        rows.insert(0, {
-            # constants.CHOICES_TEXT_FIELD: actor.get_blank_filter_text(),
-            constants.CHOICES_TEXT_FIELD: _("Blank"),
-            constants.CHOICES_VALUE_FIELD: constants.CHOICES_BLANK_FILTER_VALUE
-        })
-        rows.insert(1, {
-            # constants.CHOICES_TEXT_FIELD: actor.get_not_blank_filter_text(),
-            constants.CHOICES_TEXT_FIELD: _("Not Blank"),
-            constants.CHOICES_VALUE_FIELD: constants.CHOICES_NOT_BLANK_FILTER_VALUE
-        })
-
-    # Add None choice
-    if emptyValue is not None and not quick_search:
-        empty = dict()
-        empty[constants.CHOICES_TEXT_FIELD] = emptyValue
-        empty[constants.CHOICES_VALUE_FIELD] = None
-        rows.insert(0, empty)
-
-    return json_response_kw(count=count, rows=rows)
-    # ~ return json_response_kw(count=len(rows),rows=rows)
-    # ~ return json_response_kw(count=len(rows),rows=rows,title=_('Choices for %s') % fldname)
-
-
 class ChoiceListModel(View):
     """
     Creates a large JSON model that contains all the choicelists + choices
@@ -623,19 +434,6 @@ def XML_response(ar, tplname, context):
     return response
 
 
-def layout2html(ar, elem):
-    wl = ar.bound_action.get_window_layout()
-    # ~ print 20120901, wl.main
-    lh = wl.get_layout_handle(settings.SITE.kernel.default_ui)
-
-    items = list(lh.main.as_plain_html(ar, elem))
-    # if navigator:
-    #     items.insert(0, navigator)
-    # ~ print tostring(E.div())
-    # ~ if len(items) == 0: return ""
-    return E.form(*items)
-
-
 class MainHtml(View):
     def get(self, request, *args, **kw):
         """Returns a json struct for the main user dashboard."""
@@ -727,7 +525,7 @@ class Authenticate(View):
         # return ar.renderer.render_action_response(ar)
 
 
-class App(View):
+class Index(View):
     """
     Main app entry point,
     Also builds linoweb file for current user type.
@@ -742,11 +540,9 @@ class App(View):
                 user = request.subst_user
 
         def getit():
-
             ui = settings.SITE.plugins.react
             # if not settings.SITE.build_js_cache_on_startup:
             #     ui.renderer.build_js_cache(False)
-
             ar = BaseRequest(
                 # user=user,
                 request=request,
@@ -760,7 +556,6 @@ class App(View):
                 user=user,  # Current user
             )
             context.update(ar=ar)
-
             context = ar.get_printable_context(**context)
             env = settings.SITE.plugins.jinja.renderer.jinja_env
             template = env.get_template("react/main.html")
@@ -781,7 +576,8 @@ class UserSettings(View):
         su = request.subst_user
         su_name = request.subst_user.get_full_name() if su else ""
 
-        not_anon = u.is_authenticated if type(u.is_authenticated) == bool else u.is_authenticated()
+        # not_anon = u.is_authenticated if type(u.is_authenticated) == bool else u.is_authenticated()
+        not_anon = u.is_authenticated
 
         def getit():
             # print(20200419, settings.SITE.build_media_url(*settings.SITE.plugins.react.renderer.lino_js_parts()))
@@ -825,37 +621,3 @@ class Suggestions(View):
         return json_response(
             {"suggestions": list(suggesters[trigger].get_suggestions(query))}
         )
-
-# class Index(View):
-#     """
-#     Render the main dashboard.
-#     """
-
-#     def get(self, request, *args, **kw):
-#         # raise Exception("20171122 {} {}".format(
-#         #     get_language(), settings.MIDDLEWARE_CLASSES))
-#         ui = settings.SITE.plugins.openui5
-#         # print("20170607", request.user)
-#         # assert ui.renderer is not None
-#         ar = BaseRequest(
-#             # user=user,
-#             request=request,
-#             renderer=ui.renderer)
-#         return index_response(ar)
-
-
-# def index_response(ar):
-#     ui = settings.SITE.plugins.openui5
-
-#     main = settings.SITE.get_main_html(ar.request, extjs=ui)
-#     main = ui.renderer.html_text(main)
-#     context = dict(
-#         title=settings.SITE.title,
-#         main=main,
-#     )
-#     # if settings.SITE.user_model is None:
-#     #     user = auth.AnonymousUser.instance()
-#     # else:
-#     #     user = request.subst_user or request.user
-#     # context.update(ar=ar)
-#     return http_response(ar, 'bootstrap3/index.html', context)
