@@ -4,7 +4,7 @@
 
 SETUP_INFO = dict(
     name='lino_react',
-    version='20.6.0',
+    version='20.12.0',
     install_requires=['lino'],
     tests_require=[],
     test_suite='tests',
@@ -45,13 +45,6 @@ The central project homepage is http://react.lino-framework.org/
 SETUP_INFO.update(packages=[str(n) for n in """
 lino_react
 lino_react.react
-lino_react.projects
-lino_react.projects.teamReact
-lino_react.projects.teamReact.settings
-lino_react.projects.teamReact.tests
-lino_react.projects.lydiaReact
-lino_react.projects.lydiaReact.settings
-lino_react.projects.lydiaReact.tests
 """.splitlines() if n])
 
 
