@@ -6,7 +6,4 @@ ns = setup_from_tasks(
     blogref_url = 'http://luc.lino-framework.org',
     revision_control_system='git',
     # locale_dir='lino_extjs/extjs/locale',
-    cleanable_files=['docs/api/lino_react.*'],
-    demo_projects=[
-        'lino_react.projects.teamReact',
-        'lino_react.projects.lydiaReact'])
+    cleanable_files=['docs/api/lino_react.*'])
